@@ -32,21 +32,21 @@
  * END SYNOPSIS */
 
 #ifdef __GNUC__
-#ident "$Id: auth_sasldb.c,v 1.3 2002/02/06 15:11:26 rjs3 Exp $"
+#ident "$Id: auth_sasldb.c,v 1.5 2002/07/27 18:44:46 rjs3 Exp $"
 #endif
 
 /* PUBLIC DEPENDENCIES */
+#include "mechanisms.h"
+
 #include <string.h>
 #include <stdlib.h>
 #include <pwd.h>
-
 /* END PUBLIC DEPENDENCIES */
 
 #define RETURN(x) return strdup(x)
 
 
 #ifdef AUTH_SASLDB
-#include "mechanisms.h"
 #include "../include/sasl.h"
 #include "../include/saslplug.h"
 #include "../sasldb/sasldb.h"
@@ -132,7 +132,8 @@ auth_sasldb (
     char pw[1024];			/* pointer to passwd file entry */
     sasl_utils_t utils;
     int ret, outsize;
-    char *use_realm, realm_buf[MAXHOSTNAME];
+    const char *use_realm;
+    char realm_buf[MAXHOSTNAMELEN];
     /* END VARIABLES */
 
     init_lame_utils(&utils);
@@ -140,7 +141,7 @@ auth_sasldb (
     _sasl_check_db(&utils, (void *)0x1);
 
     if(!realm || !strlen(realm)) {
-	ret = gethostname(realm_buf,MAXHOSTNAME);
+	ret = gethostname(realm_buf,MAXHOSTNAMELEN);
 	if(ret) RETURN("NO");
 	use_realm = realm_buf;
     } else {
@@ -148,8 +149,8 @@ auth_sasldb (
     }
     
 
-    ret = _sasldb_getdata(&utils, (void *)0x1, login, realm, "userPassword",
-			  pw, 1024, &outsize);
+    ret = _sasldb_getdata(&utils, (void *)0x1, login, use_realm,
+			  "userPassword", pw, 1024, &outsize);
 
     if (ret != SASL_OK) {
 	RETURN("NO");
